@@ -18,6 +18,7 @@ Various utilities
    ~itemizer
    ~json_export
    ~json_import
+   ~listdevice
    ~listobjects
    ~listruns
    ~object_explorer
@@ -128,6 +129,17 @@ def command_list_as_table(commands, show_raw=False):
 
 
 def device_read2table(device, show_ancient=True, use_datetime=True, printing=True):
+    """
+    DEPRECATED: Use listdevice() instead.
+    """
+    warnings.warn(
+        "DEPRECATED: device_read2table() will be removed"
+        " in a future release.  Use listdevice() instead."
+        )
+    listdevice(device, show_ancient=show_ancient, use_datetime=use_datetime, printing=printing)
+
+
+def listdevice(device, show_ancient=True, use_datetime=True, printing=True):
     """
     read an ophyd device and return a pyRestTable Table
 
@@ -366,16 +378,18 @@ def listruns(
         run = cat[uid]
         start = run.metadata["start"]
         stop = run.metadata["stop"]
+        reported_exit_status = "unknown"
+        if stop is not None:
+            reported_exit_status = stop.get("exit_status", "")
 
         if (exit_status is not None
-            and stop.get("exit_status") != exit_status):
+            and reported_exit_status != exit_status):
             continue
 
         row = [
             start["uid"][:7],
-            datetime.datetime.fromtimestamp(
-                start['time']),
-            stop.get("exit_status", "")
+            datetime.datetime.fromtimestamp(start['time']),
+            reported_exit_status,
             ]
 
         for k in labels:
@@ -718,6 +732,9 @@ def show_ophyd_symbols(show_pv=True,
                        printing=True,
                        verbose=False,
                        symbols=None):
+    """
+    DEPRECATED: Use listobjects() instead.
+    """
     warnings.warn(
         "DEPRECATED: show_ophyd_symbols() will be removed"
         " in a future release.  Use listobjects() instead."
@@ -949,6 +966,32 @@ class EmailNotifications(object):
     send email notifications when requested
 
     use default OS mail utility (so no credentials needed)
+
+    EXAMPLE
+
+    Send email(s) when `feedback_limits_approached`
+    (a hypothetical boolean) is `True`::
+
+        # setup
+        from apstools.utils import EmailNotifications
+
+        SENDER_EMAIL = "instrument_user@email.host.tld"
+
+        email_notices = EmailNotifications(SENDER_EMAIL)
+        email_notices.add_addresses(
+            # This list receives email when send() is called.
+            "joe.user@goodmail.com",
+            "instrument_team@email.host.tld",
+            # others?
+        )
+
+        # ... later
+
+        if feedback_limits_approached:
+            # send emails to list
+            subject = "Feedback problem"
+            message = "Feedback is very close to its limits."
+            email_notices.send(subject, message)
     """
 
     def __init__(self, sender=None):
